@@ -32,8 +32,6 @@
 #include "gpm-kbd-backlight.h"
 #include "gsd-media-keys-window.h"
 
-#define GPM_KBD_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_KBD_BACKLIGHT, GpmKbdBacklightPrivate))
-
 struct GpmKbdBacklightPrivate
 {
     UpClient        *client;
@@ -62,7 +60,7 @@ enum {
 
 static guint signals [LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GpmKbdBacklight, gpm_kbd_backlight, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GpmKbdBacklight, gpm_kbd_backlight, G_TYPE_OBJECT)
 
 /**
  * gpm_kbd_backlight_error_quark:
@@ -495,10 +493,8 @@ gpm_kbd_backlight_control_resume_cb (GpmControl *control,
  **/
 static void
 gpm_kbd_backlight_client_changed_cb (UpClient *client,
-#if UP_CHECK_VERSION(0, 99, 0)
-                    GParamSpec *pspec,
-#endif
-                    GpmKbdBacklight *backlight)
+                                     GParamSpec *pspec,
+                                     GpmKbdBacklight *backlight)
 {
    gpm_kbd_backlight_evaluate_power_source_and_set (backlight);
 }
@@ -673,8 +669,6 @@ gpm_kbd_backlight_class_init (GpmKbdBacklightClass *klass)
                   G_TYPE_NONE,
                   1,
                   G_TYPE_UINT);
-
-   g_type_class_add_private (klass, sizeof (GpmKbdBacklightPrivate));
 }
 
 /**
@@ -690,7 +684,7 @@ gpm_kbd_backlight_init (GpmKbdBacklight *backlight)
    GVariant *u_max_brightness;
    GError   *error = NULL;
 
-   backlight->priv = GPM_KBD_BACKLIGHT_GET_PRIVATE (backlight);
+   backlight->priv = gpm_kbd_backlight_get_instance_private (backlight);
 
    backlight->priv->upower_proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
                                       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
@@ -764,13 +758,8 @@ noerr:
 
    /* Use upower for ac changed signal */
    backlight->priv->client = up_client_new ();
-#if UP_CHECK_VERSION(0, 99, 0)
    g_signal_connect (backlight->priv->client, "notify",
              G_CALLBACK (gpm_kbd_backlight_client_changed_cb), backlight);
-#else
-   g_signal_connect (backlight->priv->client, "changed",
-             G_CALLBACK (gpm_kbd_backlight_client_changed_cb), backlight);
-#endif
 
    backlight->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 
