@@ -43,8 +43,6 @@
 
 static void gpm_prefs_finalize (GObject *object);
 
-#define GPM_PREFS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_PREFS, GpmPrefsPrivate))
-
 struct GpmPrefsPrivate
 {
 	UpClient		*client;
@@ -69,7 +67,7 @@ enum {
 
 static guint signals [LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GpmPrefs, gpm_prefs, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (GpmPrefs, gpm_prefs, G_TYPE_OBJECT)
 
 /**
  * gpm_prefs_class_init:
@@ -80,7 +78,6 @@ gpm_prefs_class_init (GpmPrefsClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gpm_prefs_finalize;
-	g_type_class_add_private (klass, sizeof (GpmPrefsPrivate));
 
 	signals [ACTION_HELP] =
 		g_signal_new ("action-help",
@@ -484,7 +481,7 @@ prefs_setup_ac (GpmPrefs *prefs)
 		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "hbox_ac_brightness"));
 
 		gtk_widget_hide(widget);
-		
+
 		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_ac_display_dim"));
 
 		gtk_widget_hide(widget);
@@ -575,7 +572,8 @@ static void
 prefs_setup_ups (GpmPrefs *prefs)
 {
 	GtkWidget *widget;
-	GtkNotebook *notebook;
+	GtkWidget *notebook;
+	GtkWidget *window;
 	gint page;
 
 	const GpmActionPolicy ups_low_actions[] =
@@ -607,11 +605,17 @@ prefs_setup_ups (GpmPrefs *prefs)
 					GPM_SETTINGS_SLEEP_DISPLAY_UPS,
 					display_times);
 
+	window = gpm_window (prefs);
+	notebook = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "notebook_preferences"));
+	gtk_widget_add_events (notebook, GDK_SCROLL_MASK);
+	g_signal_connect (GTK_NOTEBOOK (notebook), "scroll-event",
+			  G_CALLBACK (gpm_dialog_page_scroll_event_cb),
+			  window);
+
 	if (prefs->priv->has_ups == FALSE) {
-		notebook = GTK_NOTEBOOK (gtk_builder_get_object (prefs->priv->builder, "notebook_preferences"));
 		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "vbox_ups"));
-		page = gtk_notebook_page_num (notebook, GTK_WIDGET (widget));
-		gtk_notebook_remove_page (notebook, page);
+		page = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), GTK_WIDGET (widget));
+		gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page);
 		return;
 	}
 
@@ -669,16 +673,13 @@ gpm_prefs_init (GpmPrefs *prefs)
 	UpDevice *device;
 	UpDeviceKind kind;
 	GpmBrightness *brightness;
-#if !UP_CHECK_VERSION(0, 99, 0)
-	gboolean ret;
-#endif
 	guint i;
 
 	GDBusProxy *proxy;
 	GVariant *res, *inner;
 	gchar * r;
 
-	prefs->priv = GPM_PREFS_GET_PRIVATE (prefs);
+	prefs->priv = gpm_prefs_get_instance_private (prefs);
 
 	prefs->priv->client = up_client_new ();
 	prefs->priv->console = egg_console_kit_new ();
@@ -721,7 +722,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 			g_error_free (error);
 		}
 
-		res = g_dbus_proxy_call_sync (proxy, "CanSuspend", 
+		res = g_dbus_proxy_call_sync (proxy, "CanSuspend",
 					      NULL,
 					      G_DBUS_CALL_FLAGS_NONE,
 					      -1,
@@ -737,7 +738,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 			g_error_free (error);
 		}
 
-		res = g_dbus_proxy_call_sync (proxy, "CanHibernate", 
+		res = g_dbus_proxy_call_sync (proxy, "CanHibernate",
 					      NULL,
 					      G_DBUS_CALL_FLAGS_NONE,
 					      -1,
@@ -776,8 +777,8 @@ gpm_prefs_init (GpmPrefs *prefs)
 			return;
 		}
 
-		res = g_dbus_proxy_call_sync (proxy, "Get", 
-					      g_variant_new( "(ss)", 
+		res = g_dbus_proxy_call_sync (proxy, "Get",
+					      g_variant_new( "(ss)",
 							     "org.freedesktop.UPower",
 							     "LidIsPresent"),
 					      G_DBUS_CALL_FLAGS_NONE,
@@ -806,15 +807,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 	brightness = gpm_brightness_new ();
 	prefs->priv->has_lcd = gpm_brightness_has_hw (brightness);
 	g_object_unref (brightness);
-#if !UP_CHECK_VERSION(0, 99, 0)
-	/* get device list */
-	ret = up_client_enumerate_devices_sync (prefs->priv->client, NULL, &error);
-	if (!ret) {
-		egg_warning ("failed to get device list: %s", error->message);
-		g_error_free (error);
-	}
-#endif
-	devices = up_client_get_devices (prefs->priv->client);
+	devices = up_client_get_devices2 (prefs->priv->client);
 	for (i=0; i<devices->len; i++) {
 		device = g_ptr_array_index (devices, i);
 		g_object_get (device,
@@ -829,7 +822,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 
 	error = NULL;
 	prefs->priv->builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (prefs->priv->builder, GPM_DATA "/gpm-prefs.ui", &error);
+	retval = gtk_builder_add_from_resource (prefs->priv->builder, "/org/mate/powermanager/preferences/gpm-prefs.ui", &error);
 
 	if (error) {
 		egg_error ("failed to load ui: %s", error->message);
@@ -875,7 +868,7 @@ gpm_prefs_finalize (GObject *object)
 	g_return_if_fail (GPM_IS_PREFS (object));
 
 	prefs = GPM_PREFS (object);
-	prefs->priv = GPM_PREFS_GET_PRIVATE (prefs);
+	prefs->priv = gpm_prefs_get_instance_private (prefs);
 
 	g_object_unref (prefs->priv->settings);
 	g_object_unref (prefs->priv->client);
